var MOApp = MOApp || {
    messages: {
        "MSG_NO_VIDEO_SOURCE":    "No video source details available...",
        "MSG_NO_CONTENTS":        "No contents returned...",
        "MSG_RETRIEVE_FAILED":    "The attempt to retrieve the full size version of this object has failed.",
        "MSG_NO_FIGURE_URL":      "No location specified from which to retrieve figure image...",
        "MSG_NO_TABLE_URL":       "No location specified from which to retrieve table...",
        "MSG_NO_VIDEO_URL":       "No location specified from which to retrieve multimedia object...",
        "MSG_VIDEO_TEXT":         "This video can only be played using <a href=\"http://get.adobe.com/flashplayer/\">Flash Player</a>.",
        "MSG_INVALID_DIALOGTYPE": "Unknown dialog type requested: ",
        "MSG_NO_MEDIA_TYPE":      "Invalid or missing media type: "
    },
    /**
     * Carry out any processing required on AJAX data received
     *
     * @param {string}  dlgName
     * @param {integer} dlgHeight
     * @param {integer} dlgWidth
     * @param {string}  mimeType
     * @param {string}  videoUrl
     */
    postProcessing: function(dlgName, dlgHeight, dlgWidth, mimeType, videoUrl) {
        //if (AIPApp.consoleOK) {console.info("postProcessing() parameters:\n\n" +
        //                    "1. dlgName: " + dlgName.attr("id") + "\n" +
        //                    "2. dlgHeight: " + dlgHeight + "\n" +
        //                    "3. dlgWidth: " + dlgWidth + "\n" +
        //                    "4. mimeType: " + mimeType + "\n" +
        //                    "5. videoUrl: " + videoUrl + "\n");}
        var dialogType = dlgName.attr("id");
        switch (dialogType) {
        case "figuredialog":
            break;
        case "tabledialog":
            break;
        case "videodialog":
            if (videoUrl) {
                jwplayer("videodialog").setup({
                    file: videoUrl,
                    fallback: false
                });
            } else {
                alert(MOApp.messages.MSG_NO_VIDEO_SOURCE);
            }
            break;
        default:
            alert(MOApp.messages.MSG_INVALID_DIALOGTYPE + dialogType);
            break;
        }
    },
    /**
     *
     * @param {object} $here           Here we are!
     * @param {object} dlgName         Dialog to be used
     * @param {string} url             Target for AJAX call
     * @param {string} dlgTitle        Dialog title
     * @param {string} citation        Citation string
     * @param {string} container       High(er)-level container block
     * @param {string} additionalText  Any additional text required for display
     *
     */
    processAjax: function($here, dlgName, url, dlgTitle, citation, container, additionalText) {
        //
        //if (AIPApp.consoleOK) {console.info("processAjax() parameters:\n\n" +
        //                    "1. here: Here" + "\n" +
        //                    "2. dlgName: " + dlgName + "\n" +
        //                    "3. url: " + url + "\n" +
        //                    "4. dlgTitle: " + dlgTitle + "\n" +
        //                    "5. citation: " + citation + "\n" +
        //                    "6. container: " + container + "\n" +
        //                    "7. additionalText: " + additionalText + "\n");}
        //
        // Set up the dialog window size...
        var dlgWidth  = (dlgName.attr("id") === "videodialog") ? "auto" : $(window).width() * 0.6,     // Default width...
            dlgHeight = (dlgName.attr("id") === "videodialog") ? "auto" : $(window).height() * 0.8,    // Default height...
            mimeType = "",
            videoUrl = "";
        // Make the call...
        $.ajax({
            type: "GET",
            url: url,
            dataType: "html",
            success: function(resp, statusText) {
                // Add the response to our DOM without accidentally stripping out any MathML
                dlgName.get(0).innerHTML = resp;
                // Find the contents we're interested in
                var $multimediaElement = $(".multimediaContainer", dlgName).get(0),
                    $dlgContent = $(".multimediaContainer", dlgName);
                // Make sure our dialog only contains that bit
                dlgName.get(0).innerHTML = "<" + $multimediaElement.tagName + " id=\"" + $multimediaElement.id + "\" class=\""  +
                    $multimediaElement.getAttribute("class") + "\">" + $multimediaElement.innerHTML + "</" + $multimediaElement.tagName + ">";
                if ($dlgContent.length > 0) {
                    // Grab the url and mime type for the video...
                    mimeType = $(".mediaFormatType", dlgName).text();
                    videoUrl = $(".mediaSource", dlgName).text();
                    // Set the width and height as a proportion of the current viewport size
                    dlgName.dialog({
                        title: dlgTitle,
                        height: dlgHeight,
                        width: dlgWidth
                    });
                    MathJax.Hub.Queue(["Typeset", MathJax.Hub, dlgName.get(0)]);
                    // Just grab the first such link. When logged in as admin there are more...
                    dlgName.find(".dialogCitation span:first").after(citation);
                    if (additionalText) {
                        dlgName.append("<span class=\"additionalText\">" + additionalText + "</span>");
                    }

                    var processImageURL =  function($tImage, reResult) {
                        $tImage.each(function(index) {
                            var docServerBase = "/docserver/ahah/fulltext/",
                                $here = $(this),
                                newUrl = "",
                                thisSrc = $here.attr("src");
                            if (thisSrc.match(/\.zip$/) && thisSrc.indexOf("docserver") === -1) {
                                $here.css({"display":"none"});
                            }

                            if (thisSrc.match(/\.gif$/) && reResult !== null && thisSrc.indexOf("docserver") === -1) {
                                newUrl = docServerBase + reResult[1] + "/" + thisSrc.replace(".gif", ".jpg");
                                $here.attr("src", newUrl);
                            }

                            if (thisSrc.match(/\.jpg$/) && reResult !== null && thisSrc.indexOf("docserver") === -1) {
                                newUrl = docServerBase + reResult[1] + "/" + thisSrc;
                                $here.attr("src", newUrl);
                            }
                        });
                    };

                    // Manage docserver baseUrl
                    var pathName = window.location.pathname,
                        pattern1 = /^\/.*\/(.*\/.*\/.*\/.*\/.*)\/.*\/.*$/,
                        reResult = pathName.match(pattern1),
                        $tImage = "";
                    //
                    if ($(".captionContainer").get(0)) {
                        //console.log("currentSection:" + aipProps.currentSection);
                        $tImage = $("span.figDesc .capture-id img");
                        processImageURL($tImage, reResult);
                    }

                    if ($(".tabContainer").get(0)) {
                        //console.log("currentSection:" + aipProps.currentSection);
                        $tImage = $("div.tabContainer table.bm tbody tr td img");
                        processImageURL($tImage, reResult);
                    }

                    if ($(".tabContainer").get(0)) {
                        //console.log("currentSection:" + aipProps.currentSection);
                        $tImage = $("div.tabContainer table.bm thead tr th img");
                        processImageURL($tImage, reResult);
                    }

                    dlgName.dialog("open");
                    MOApp.postProcessing(dlgName, dlgHeight, dlgWidth, mimeType, videoUrl);
                } else {
                    alert(MOApp.messages.MSG_NO_CONTENTS);
                }

            },
            error: function(req, statusText) {
                alert(MOApp.messages.MSG_RETRIEVE_FAILED);
            },
            complete: function(req, statusText) {
                $here.addClass("cursorPointer").removeClass("cursorWait");
                $here.closest(container).removeClass("cursorWait opened");
            }
        });
    }
};

$(document).ready(function() {
    var hiddenContext = $("#hiddenContext").text(),
        // Identify the dialog "hooks"...
        figureDialog = $("#figuredialog"),
        tableDialog = $("#tabledialog"),
        videoDialog = $("#videodialog"),
        multimediaDialog = $("#multimediadialog"),
        collectionsDialog = $("#collectionDialogHook"),

        // Declare some default dialog attributes
        stdDialogOptions = {
            autoOpen: false,
            modal: true,
            position: {
                my: "center",
                at: "center",
                of: $(window)
            },
            resizable: true
        },
        $itemMetadataNode = $(".dataandmedia").find(".hiddenjsdiv.itemmetadata"),
        itemCitation = $itemMetadataNode.find(".metadata_citation").html(),
        /**
         * Clear dialog objects...
         *
         * @param {jQuery object} dialogObject
         */
        clearDialog = function(dlgObject) {
            dlgObject.find(".multimediaContainer").remove();
            dlgObject.find(".dialogCitation").remove();
        },
        /**
         * Set up for retrieving media objects for Full Text tab...
         *
         * @param {jQuery event object} e
         * @param {string}              mediaType  figure|table|video
         */
        prepareMultimedia1 = function(e, mediaType) {
            var $here = $(e.currentTarget),
                alertMsg,
                citation,
                ftDialogTitle,
                $ftHook,
                ftText,
                $itemMetadata,
                $mediaMetadata,
                $semaphore = $here.closest("#html-body"),
                url;
            // Stop any link action...
            e.preventDefault();
            // Use a class as a semaphore...
            if (!$semaphore.hasClass("opened")) {
                $semaphore.addClass("opened cursorWait");
                $here.removeClass("cursorPointer").addClass("cursorWait");
                $itemMetadata = $here.parents(".articlefulltext").find(".hiddenjsdiv.itemmetadata");
                citation = $itemMetadata.find(".metadata_citation").html();
                switch (mediaType) {
                case "figure":
                    $mediaMetadata = $here.closest(".figure");
                    url = hiddenContext + $mediaMetadata.find(".image a").attr("id");
                    $ftHook = figureDialog;
                    ftDialogTitle = $mediaMetadata.find(".caption .captionLabel .label").text();
                    ftText = "";
                    alertMsg = MOApp.messages.MSG_NO_FIGURE_URL;
                    break;
                case "table":
                    $mediaMetadata = $here.closest(".table");
                    url = hiddenContext + $mediaMetadata.find(".image a").attr("id");
                    $ftHook = tableDialog;
                    ftDialogTitle = $mediaMetadata.find(".caption .captionLabel .label").text();
                    ftText = "";
                    alertMsg = MOApp.messages.MSG_NO_TABLE_URL;
                    break;
                case "media":
                    $mediaMetadata = null;
                    url = hiddenContext + "/content/multimedia/" + $here.text();
                    $ftHook = videoDialog;
                    ftDialogTitle = "Multimedia object";
                    ftText = MOApp.messages.MSG_VIDEO_TEXT;
                    alertMsg = MOApp.messages.MSG_NO_VIDEO_URL;
                    break;
                default:
                    $mediaMetadata = null;
                    url = "";
                    $ftHook = null;
                    ftDialogTitle = "";
                    alertMsg = MOApp.messages.MSG_NO_MEDIA_TYPE + mediaType;
                    break;
                }
                if (url) {
                    MOApp.processAjax($here, $ftHook, url, ftDialogTitle, citation, "#html-body", "");
                } else {
                    alert(alertMsg);
                }
            }
        },
        /**
         * Set up for retrieving media objects for Data and Media tab...
         *
         * @param {jQuery event object} e
         * @param {string}              mediaType  figure|table|video
         * @param {string}              semaphore  jQuery class selector for flag
         */
        prepareMultimedia2 = function(e, mediaType, semaphore) {
            var $here = $(e.currentTarget),
                alertMsg,
                $ftHook,
                ftDialogTitle,
                ftText,
                $itemMetadata,
                $mediaMetadata,
                $semaphore = $here.closest(semaphore),
                url;
            // Stop any link action...
            e.preventDefault();
            // Use a class as a semaphore...
            if (!$semaphore.hasClass("opened")) {
                $semaphore.addClass("opened cursorWait");
                $here.removeClass("cursorPointer").addClass("cursorWait");
                $itemMetadata = $here.parents(".dataandmedia").find(".hiddenjsdiv.itemmetadata");
                switch (mediaType) {
                case "figure":
                    $mediaMetadata = $here.parents(".singleFigureContainer").find(".hiddenjsdiv.mediametadata");
                    $ftHook = figureDialog;
                    ftText = "";
                    alertMsg = MOApp.messages.MSG_NO_FIGURE_URL;
                    break;
                case "table":
                    $mediaMetadata = $here.parents(".singleTableContainer").find(".hiddenjsdiv.mediametadata");
                    $ftHook = tableDialog;
                    ftText = "";
                    alertMsg = MOApp.messages.MSG_NO_TABLE_URL;
                    break;
                case "media":
                    $mediaMetadata = $here.parents(".singleMultimediaContainer").find(".hiddenjsdiv.mediametadata");
                    $ftHook = videoDialog;
                    ftText = MOApp.messages.MSG_VIDEO_TEXT;
                    alertMsg = MOApp.messages.MSG_NO_VIDEO_URL;
                    break;
                default:
                    $mediaMetadata = null;
                    url = null;
                    $ftHook = null;
                    ftDialogTitle = "";
                    alertMsg = MOApp.messages.MSG_NO_MEDIA_TYPE + mediaType;
                    break;
                }
                ftDialogTitle = $mediaMetadata.find(".metadata_title").text();
                url = hiddenContext + $mediaMetadata.find(".metadata_webId").text();
                if (url) {
                    MOApp.processAjax($here, $ftHook, url, ftDialogTitle, itemCitation, semaphore, ftText);
                } else {
                    alert(MOApp.messages.MSG_NO_FIGURE_URL);
                }
            }
        },
        /**
         * Set up for showing video/podcasts for Collections page, no Ajax required...
         *
         * @param {jQuery event object} e
         */
        processCollectionsVidPodcasts = function(e) {
            var $here = $(e.currentTarget),
                $mediaContainer = $here.parents(".singleVideoPodcastContainer"),
                dlgTitle = $mediaContainer.find('.metadata_title').text(),
                mediaPath = $mediaContainer.find('.metadata_multimediaFile').text(),
                thumbnailSrc = $mediaContainer.find('.metadata_thumbnailFile').text(),
                authorsNoLink = $mediaContainer.find('.authorsWithPopup').text(),
                copyright = $mediaContainer.find('.vidPodcastCopyright').text(),
                uploaded = $mediaContainer.find('.vidPodcastUploadDate').text(),
                length = $mediaContainer.find('.vidPodcastLength').text(),
                dlgName = collectionsDialog,
                playerId = "jwPlayerHook",
                metaDataForDialog = "",
                mediaSrc = document.location['origin'] + mediaPath;

            // Stop any link action...
            e.preventDefault();

            dlgName.dialog({
                title: dlgTitle,
                height: 515,
                width: 565
            });

            dlgName.append("<div id=\""+playerId+"\"></div><div id=\"collectionDialogMetadata\"></div>");

            jwplayer(playerId).setup({
                file: mediaSrc,
                width: 523,
                height: 289,
                fallback: true
            });

            metaDataForDialog = dlgTitle !== null ? "<p class=\"vidPodcastTitle\">"+dlgTitle+"</p>" : "<p class=\"vidPodcastTitle\">Collections Video</p>";
            if(authorsNoLink !== null && authorsNoLink.length > 0){
                authorsNoLink = authorsNoLink.replace('By:', '');
                metaDataForDialog += "<p>"+authorsNoLink+"</p>";
            }
            metaDataForDialog += copyright !== null ? "<p>"+copyright+"</p>" : "";
            metaDataForDialog += uploaded !== null ? "<p>"+uploaded+"</p>" : "";
            metaDataForDialog += length !== null ? "<p>"+length+"</p>" : "";

            $('#collectionDialogMetadata').html(metaDataForDialog).addClass('vidPodcastMetadata');

            dlgName.dialog("open");


         //end 3
    };


    // Give the dialog boxes some characteristics...
    figureDialog.dialog(stdDialogOptions);
    tableDialog.dialog(stdDialogOptions);
    videoDialog.dialog(stdDialogOptions);
    multimediaDialog.dialog(stdDialogOptions);
    collectionsDialog.dialog(stdDialogOptions);

    // Remove contents as the dialog is closed
    figureDialog.bind("dialogbeforeclose", clearDialog(figureDialog));
    tableDialog.bind("dialogbeforeclose", clearDialog(tableDialog));
    videoDialog.bind("dialogbeforeclose", clearDialog(videoDialog));
    multimediaDialog.bind("dialogbeforeclose", clearDialog(multimediaDialog));
    collectionsDialog.bind("dialogbeforeclose", clearDialog(multimediaDialog));

    // Process request for figure from Fulltext tab...
    $("#html-body .figure .image a").live("click", function(e) {
        prepareMultimedia1(e, "figure");
    });

    // Process request for table from Fulltext tab...
    $("#html-body .table .image a").live("click", function(e) {
        prepareMultimedia1(e, "table");
    });

    // Process request for multimedia object from Fulltext tab...
    $("#html-body a.media-link span").live("click", function(e) {
        prepareMultimedia1(e, "media");
    });

    // Process request for figure from Data and Media tab...
    $(".figureSmallImageContainer img.showFullVersion, .figureSmallImageContainer p.click2view").live("click", function(e) {
        prepareMultimedia2(e, "figure", ".figuresblock");
    });

    // Process request for table...
    $(".tableSmallImageContainer img.showFullVersion, .tableSmallImageContainer p.click2view").live("click", function(e) {
        prepareMultimedia2(e, "table", ".tablesblock");
    });

    // Process request for video...
    $(".multimediaSmallImageContainer img.showFullVersion, .multimediaSmallImageContainer p.click2view").live("click", function(e) {
        prepareMultimedia2(e, "media", ".multimediablock");
    });

    //Process request for video/podcast from collections page
    $(".triggerVidPodcastDialog").live("click", function(e) {
        processCollectionsVidPodcasts(e);
    });

    // Submit 'download as PPT' form from text link
    $(".downloadPpt").live("click", function(e) {
        var $pptForm = $(this).closest("form"),
            articleCitation = $(".itemCitation").text();
        $pptForm.find("input[name='citation']").val(articleCitation);
        $pptForm.submit();
    });

});
