var REFApp = REFApp || {
    /**
     * Fetches reference matches using an AJAX call
     *
     * @param {itemId} The id of the item
     * @param {mode}   The mode of the call (either "ref" or "fulltext"
     * 
     */
    fetchReferenceMatches: function(itemId, mode) {
        if (mode === "fulltext") {
            return;
        }

        var hiddenContext = $("#hiddenContext").text();
        var matchesUrl = hiddenContext + "/references/matchedRefsForItem.action?itemId=" + itemId;
        
        var spinnerLocations = $(".refcontainer > .refbody");
        spinnerLocations.each(function () {
            var self = $(this);
            if (!self.data("span")) {
                self.data("span", true);
                self.append('<span class="refmatchwrapper"><img src="/images/jp/spinner.gif" alt="Loading matches" /></span>');
            }
        });
        $.getJSON(matchesUrl, function(response) {
            var aRef,
                consoleMsg,
                loop,
                match,
                matches,
                mLoop,
                mLen,
                newLinkHtml,
                $target,
                $refContainer,
                $groupRef,
                operation,
                tmp = "";
            $(".refmatchwrapper").remove();
            if (response !== null) {
                // if (AIPApp.consoleOK) {console.info("fetchReferenceMatches() AJAX response received...\n\n" + JSON.stringify(response, null, ' ') + "\n\n");}
                mLen = response.referenceItems.length;
                for (loop = 0; loop < mLen; loop++) {
                    aRef = response.referenceItems[loop];
                    tmp = mode === "ref" ? "#ref-" + aRef.id : "#" + aRef.id;
                    $target = $(tmp);
                    $refContainer = $target.find(".refcontainer");
                    $groupRef = $target.find(".groupref:first");
                    // On the full text tab we should be inside the div
                    if ($refContainer.size() > 0) {
                        $target = $refContainer;
                        operation = function(x) { $target.append(x); };
                    } else 
                    // On the references tab we should go before any grouprefs
                    if ($groupRef.size() > 0) {
                        $target = $groupRef;
                        operation = function(x) { $target.before(x); };
                    } else {
                        operation = $target.append;
                        operation = function(x) { $target.append(x); };
                    }
                    if ($target.size() > 0) {
                        newLinkHtml = "<span class='refmatch'>";
                        matches = aRef.matches.length;
                        for (mLoop = 0; mLoop < matches; mLoop++) {
                            match = aRef.matches[mLoop];
                            if (match.thirdParty.name !== "CrossRef matcher") {
                                newLinkHtml += " [ <a href='" + match.linkUri + 
                                               "' class='externallink' rel='external' title='Link to external reference'>" + match.thirdParty.name +  
                                               "</a>]";
                            }
                        }
                        newLinkHtml += "</span>";
                        operation(newLinkHtml);
                    }
                }
            } 
        });

    }
};

$(document).ready(function() {
    var itemWebId = $("#itemWebIdForRefs").text();
    if (itemWebId) {
        var referenceLoadingHandler = function() {
    		REFApp.fetchReferenceMatches(itemWebId, "ref");
    		$("#references").unbind("click", referenceLoadingHandler);
    	};
    	$("#references").bind("click", referenceLoadingHandler);
    }
});
